"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rgbaToHex = exports.hexToRgba = void 0;
/**
 * Converts a hexadecimal color string to an RGBA color array.
 *
 * @param {string} hex - The hexadecimal color string to convert.
 * @param {Object} options - The options object.
 * @param {number} [options.fixed=3] - The number of decimal places to fix the alpha value to.
 * @param {number[]} [options.supportedLengths=[3, 4, 6, 8]] - The supported lengths of the hexadecimal color string.
 *
 * @returns {number[]} - An array containing the red, green, blue, and alpha values of the color, with red, green, and blue in the range 0 to 255 and alpha in the range 0 to 1.
 * @throws {Error} - If the input string is not a valid hexadecimal color string.
 *
 * @example
 * hexToRgba('#fff');  // returns [255, 255, 255, 1]
 * hexToRgba('#fffa'); // returns [255, 255, 255, 0.667]
 * hexToRgba('#ffffff'); // returns [255, 255, 255, 1]
 * hexToRgba('#ffffffbc'); // returns [255, 255, 255, 0.737]
 * hexToRgba('#f00'); // returns [255, 0, 0, 1]
 * hexToRgba('#ff0000'); // returns [255, 0, 0, 1]
 * hexToRgba('#ff0000ff'); // returns [255, 0, 0, 1]
 *
 * @author chatGPT
*/
function hexToRgba(hex, options) {
    options = Object.assign({
        fixed: 3,
        supportedLengths: [3, 4, 6, 8]
    }, options);
    // Parse the hexadecimal color string into its component parts
    const hexColor = hex.match(/(?<=^#)[a-f\d]{3,8}$/i)?.[0];
    // If the color string is not in the correct format, return an error
    if (!hexColor || !options.supportedLengths.includes(hexColor.length)) {
        throw new Error('Invalid hexadecimal color string');
    }
    // Extract the red, green, blue and alpha? values from the hexadecimal string
    let r, g, b, a;
    if ([3, 4].includes(hexColor.length)) {
        r = parseInt(hexColor[0] + hexColor[0], 16);
        g = parseInt(hexColor[1] + hexColor[1], 16);
        b = parseInt(hexColor[2] + hexColor[2], 16);
        a = hexColor.length === 4 ? parseInt(hexColor.slice(3, 4), 16) / 15 : 1;
    }
    else {
        r = parseInt(hexColor[0] + hexColor[1], 16);
        g = parseInt(hexColor[2] + hexColor[3], 16);
        b = parseInt(hexColor[4] + hexColor[5], 16);
        a = hexColor.length === 8 ? parseInt(hexColor.slice(6, 8), 16) / 255 : 1;
    }
    a = parseFloat(a.toFixed(options.fixed));
    // Return an RGBA color array
    return [r, g, b, a];
}
exports.hexToRgba = hexToRgba;
function rgbaToHex(rgba, options) {
    options = Object.assign({
        fixed: 3,
        lengthType: 4,
        addHash: true
    }, options);
    let output = '';
    if (options.addHash) {
        output += '#';
    }
    if (options.lengthType === 4) {
        for (let i = 0; i < rgba.length - 1; i++) {
            output += Math.ceil(rgba[i] / 17).toString(16);
        }
        output += Math.ceil(rgba[3] * 255 / 17).toString(16);
    }
    else {
        for (let i = 0; i < rgba.length - 1; i++) {
            output += rgba[i].toString(16);
        }
        output += (rgba[3] * 255).toString(16);
    }
    return output;
}
exports.rgbaToHex = rgbaToHex;
